@@ -92,7 +92,9 @@ module.exports = [
       'no-import-assign': 'off',
       ...reactjs.configs.recommended.rules,
       ...reactjs.configs['jsx-runtime'].rules,
-      'react/jsx-uses-react': 'error',
+      'react/prop-types': 'off',
+      'react/react-in-jsx-scope': 0,
+      'react/jsx-uses-react': 0,
       'react/jsx-uses-vars': 'error',
       'no-unused-vars': 'off',
       'unused-imports/no-unused-imports': 'error',
