@@ -21,7 +21,7 @@ from pgadmin.browser.server_groups.servers.types import ServerType
 from pgadmin.browser.utils import PGChildNodeView
 from pgadmin.utils.ajax import make_json_response, bad_request, forbidden, \
     make_response as ajax_response, internal_server_error, unauthorized, gone
-from pgadmin.utils.crypto import encrypt, decrypt, pqencryptpassword
+from pgadmin.utils.crypto import encrypt, decrypt
 from pgadmin.utils.menu import MenuItem
 from pgadmin.tools.sqleditor.utils.query_history import QueryHistory
 from pgadmin.tools.user_management.PgAdminPermissions import AllPermissionTypes
@@ -31,7 +31,7 @@ from config import PG_DEFAULT_DRIVER
 from pgadmin.model import db, Server, ServerGroup, User, SharedServer
 from pgadmin.utils.driver import get_driver
 from pgadmin.utils.master_password import get_crypt_key
-from pgadmin.utils.exception import CryptKeyMissing
+from pgadmin.utils.exception import CryptKeyMissing, ConnectionLost
 from pgadmin.tools.schema_diff.node_registry import SchemaDiffRegistry
 from pgadmin.browser.server_groups.servers.utils import \
     (is_valid_ipaddress, get_replication_type, convert_connection_parameter,
@@ -43,6 +43,7 @@ from sqlalchemy.orm.attributes import flag_modified
 from pgadmin.utils.preferences import Preferences
 from .... import socketio as sio
 from pgadmin.utils import get_complete_file_path
+from pgadmin.settings.utils import with_object_filters
 
 
 def has_any(data, keys):
@@ -166,6 +167,7 @@ class ServerModule(sg.ServerGroupPluginModule):
         server.tunnel_password = sharedserver.tunnel_password
         server.save_password = sharedserver.save_password
         server.tunnel_identity_file = sharedserver.tunnel_identity_file
+        server.tunnel_prompt_password = sharedserver.tunnel_prompt_password
         if hasattr(server, 'connection_params') and \
             hasattr(sharedserver, 'connection_params') and \
             'passfile' in server.connection_params and \
@@ -220,8 +222,25 @@ class ServerModule(sg.ServerGroupPluginModule):
 
         return servers
 
+    def has_tag(self, server, object_filters):
+        try:
+            # No tags filter, show all
+            if len(object_filters['tags']) == 0:
+                return True
+
+            # No tags on server, don't show
+            if server.tags is None or len(server.tags) == 0:
+                return False
+
+            # Check if any of the tag exists
+            return any([t['text'] in object_filters['tags']
+                        for t in server.tags])
+        except Exception as _:
+            return True
+
+    @with_object_filters
     @pga_login_required
-    def get_nodes(self, gid):
+    def get_nodes(self, gid, object_filters):
         """Return a JSON document listing the server groups for the user"""
 
         hide_shared_server = get_preferences()
@@ -241,6 +260,10 @@ class ServerModule(sg.ServerGroupPluginModule):
             wal_paused = None
             server_type = 'pg'
             user_info = None
+
+            if not self.has_tag(server, object_filters):
+                continue
+
             try:
                 manager = driver.connection_manager(server.id)
                 conn = manager.connection()
@@ -391,6 +414,7 @@ class ServerModule(sg.ServerGroupPluginModule):
                 tunnel_authentication=0,
                 tunnel_identity_file=None,
                 tunnel_keep_alive=0,
+                tunnel_prompt_password=0,
                 shared=True,
                 connection_params=data.connection_params,
                 prepare_threshold=data.prepare_threshold
@@ -627,12 +651,18 @@ class ServerNode(PGChildNodeView):
         in_recovery = None
         wal_paused = None
         if connected:
-            status, result, in_recovery, wal_paused =\
-                recovery_state(conn, manager.version)
-            if not status:
+            try:
+                status, result, in_recovery, wal_paused =\
+                    recovery_state(conn, manager.version)
+
+                if not status:
+                    connected = False
+                    manager.release()
+                    errmsg = "{0} : {1}".format(server.name, result)
+
+            except ConnectionLost:
                 connected = False
                 manager.release()
-                errmsg = "{0} : {1}".format(server.name, result)
 
         return make_json_response(
             result=self.blueprint.generate_browser_node(
@@ -719,6 +749,7 @@ class ServerNode(PGChildNodeView):
         return make_json_response(success=1,
                                   info=gettext("Server deleted"))
 
+    @permissions_required(AllPermissionTypes.object_register_server)
     @pga_login_required
     def update(self, gid, sid):
         """Update the server settings"""
@@ -743,6 +774,8 @@ class ServerNode(PGChildNodeView):
             'port': 'port',
             'db': 'maintenance_db',
             'username': 'username',
+            'password': 'password',
+            'save_password': 'save_password',
             'gid': 'servergroup_id',
             'comment': 'comment',
             'role': 'role',
@@ -759,6 +792,7 @@ class ServerNode(PGChildNodeView):
             'tunnel_username': 'tunnel_username',
             'tunnel_authentication': 'tunnel_authentication',
             'tunnel_identity_file': 'tunnel_identity_file',
+            'tunnel_prompt_password': 'tunnel_prompt_password',
             'tunnel_keep_alive': 'tunnel_keep_alive',
             'shared': 'shared',
             'shared_username': 'shared_username',
@@ -876,9 +910,16 @@ class ServerNode(PGChildNodeView):
                               sharedserver):
 
         idx = 0
+
+        crypt_key_present, crypt_key = get_crypt_key()
+        if not crypt_key_present:
+            raise CryptKeyMissing
+
         for arg in config_param_map:
             if arg in data:
                 value = data[arg]
+                if arg == 'password':
+                    value = encrypt(data[arg], crypt_key)
                 # sqlite3 do not have boolean type so we need to convert
                 # it manually to integer
                 if 'shared' in data and not data['shared']:
@@ -910,7 +951,7 @@ class ServerNode(PGChildNodeView):
                     )
 
     @pga_login_required
-    def list(self, gid):
+    def list(self, gid, object_filters):
         """
         Return list of attributes of all servers.
         """
@@ -1019,6 +1060,8 @@ class ServerNode(PGChildNodeView):
             'host': server.host,
             'port': server.port,
             'db': server.maintenance_db,
+            'password': server.password,
+            'save_password': server.save_password,
             'shared': server.shared if config.SERVER_MODE else None,
             'shared_username': server.shared_username
             if config.SERVER_MODE else None,
@@ -1046,6 +1089,8 @@ class ServerNode(PGChildNodeView):
             'tunnel_username': tunnel_username,
             'tunnel_identity_file': server.tunnel_identity_file
             if server.tunnel_identity_file else None,
+            'tunnel_prompt_password': server.tunnel_prompt_password
+            if server.tunnel_identity_file else 0,
             'tunnel_authentication': tunnel_authentication,
             'tunnel_keep_alive': tunnel_keep_alive,
             'kerberos_conn': bool(server.kerberos_conn),
@@ -1172,6 +1217,8 @@ class ServerNode(PGChildNodeView):
                 tunnel_authentication=1 if data.get('tunnel_authentication',
                                                     False) else 0,
                 tunnel_identity_file=data.get('tunnel_identity_file', None),
+                tunnel_prompt_password=1 if data.get('tunnel_prompt_password',
+                                                     True) else 0,
                 tunnel_keep_alive=data.get('tunnel_keep_alive', 0),
                 shared=data.get('shared', None),
                 shared_username=data.get('shared_username', None),
@@ -1379,6 +1426,19 @@ class ServerNode(PGChildNodeView):
             }
         )
 
+    def is_prompt_tunnel_password(self, server):
+        """
+        This function will check whether to prompt tunnel password or not.
+        """
+        prompt_tunnel_password = True
+        # In case of identity file check the value of tunnel_prompt_password.
+        if server.tunnel_password is not None or \
+            (server.tunnel_identity_file is not None and
+             server.tunnel_prompt_password != 1):
+            prompt_tunnel_password = False
+
+        return prompt_tunnel_password
+
     def connect(self, gid, sid, is_qt=False, server=None):
         """
         Connect the Server and return the connection object.
@@ -1462,11 +1522,12 @@ class ServerNode(PGChildNodeView):
 
         # If server using SSH Tunnel
         if server.use_ssh_tunnel:
-            if 'tunnel_password' not in data:
-                if server.tunnel_password is None:
-                    prompt_tunnel_password = True
-                else:
-                    tunnel_password = server.tunnel_password
+            if 'tunnel_password' not in data and \
+                    server.tunnel_password is None:
+                prompt_tunnel_password = self.is_prompt_tunnel_password(server)
+            elif 'tunnel_password' not in data and \
+                    server.tunnel_password is not None:
+                tunnel_password = server.tunnel_password
             else:
                 tunnel_password = data['tunnel_password'] \
                     if 'tunnel_password' in data else ''
@@ -1522,6 +1583,10 @@ class ServerNode(PGChildNodeView):
             return self.get_response_for_password(
                 server, 428, prompt_password, prompt_tunnel_password)
 
+        # Check whether to prompt for the tunnel password in case if
+        # password is saved in server object or in data.
+        prompt_tunnel_password = self.is_prompt_tunnel_password(server)
+
         try:
             status, errmsg = conn.connect(
                 password=password,
@@ -1531,7 +1596,7 @@ class ServerNode(PGChildNodeView):
             )
         except Exception as e:
             return self.get_response_for_password(
-                server, 401, True, True,
+                server, 401, not server.save_password, prompt_tunnel_password,
                 getattr(e, 'message', str(e)))
 
         if not status:
@@ -1543,7 +1608,8 @@ class ServerNode(PGChildNodeView):
                 return internal_server_error(errmsg)
 
             return self.get_response_for_password(
-                server, 401, True, True, errmsg)
+                server, 401, not server.save_password,
+                prompt_tunnel_password, errmsg)
         else:
             if save_password and config.ALLOW_SAVE_PASSWORD:
                 try:
@@ -1815,16 +1881,11 @@ class ServerNode(PGChildNodeView):
                     return unauthorized(gettext("Incorrect password."))
 
             # Hash new password before saving it.
-            if manager.sversion >= 100000:
-                password = conn.pq_encrypt_password_conn(data['newPassword'],
-                                                         manager.user)
-                if password is None:
-                    # Unable to encrypt the password so used the
-                    # old method of encryption
-                    password = pqencryptpassword(data['newPassword'],
-                                                 manager.user)
-            else:
-                password = pqencryptpassword(data['newPassword'], manager.user)
+            password = conn.pq_encrypt_password_conn(data['newPassword'],
+                                                     manager.user)
+            if password is None:
+                return internal_server_error(errormsg="Unable to"
+                                                      " change the password.")
 
             SQL = render_template(
                 "/servers/sql/#{0}#/change_password.sql".format(
