@@ -5,7 +5,7 @@
 CREATE UNIQUE INDEX IF NOT EXISTS "Idx_$%{}[]()&*^!@""'`\/#"
     ON public.test_table_for_indexes USING btree
     (id DESC NULLS LAST, name COLLATE pg_catalog."POSIX" text_pattern_ops DESC NULLS LAST)
-    WITH (fillfactor=10)
+    WITH (fillfactor=10, deduplicate_items=True)
     TABLESPACE pg_default
     WHERE id < 100;
 
