@@ -1,7 +1,7 @@
 CREATE UNIQUE INDEX "Idx3_$%{}[]()&*^!@""'`\/#"
     ON public.test_table_for_indexes USING btree
     (id ASC NULLS LAST, (lower(name)) COLLATE pg_catalog."POSIX" text_pattern_ops ASC NULLS LAST)
-    WITH (fillfactor=10)
+    WITH (fillfactor=10, deduplicate_items=True)
     TABLESPACE pg_default
     WHERE id < 100;
 
