@@ -10,7 +10,6 @@
 import _ from 'lodash';
 import getApiInstance from '../../../static/js/api_instance';
 import { AllPermissionTypes, BROWSER_PANELS } from './constants';
-import React from 'react';
 import ObjectNodeProperties from '../../../misc/properties/ObjectNodeProperties';
 import ErrorBoundary from '../../../static/js/helpers/ErrorBoundary';
 import toPx from '../../../static/js/to_px';
@@ -122,6 +121,7 @@ define('pgadmin.browser.node', [
         callback: 'refresh',
         priority: 2,
         label: gettext('Refresh...'),
+        shortcut_preference: ['browser', 'sub_menu_refresh'],
         enable: true,
       }]);
 
@@ -137,10 +137,12 @@ define('pgadmin.browser.node', [
           data: {
             'action': 'edit',
           },
+          shortcut_preference: ['browser', 'sub_menu_properties'],
           enable: _.isFunction(self.canEdit) ?
             function() {
               return !!(self.canEdit(...arguments));
             } : (!!self.canEdit),
+          permission: self.type == 'server' ? AllPermissionTypes.OBJECT_REGISTER_SERVER : undefined,
         }]);
       }
 
@@ -152,16 +154,17 @@ define('pgadmin.browser.node', [
           applies: ['object', 'context'],
           callback: 'delete_obj',
           priority: self.dropPriority,
-          label: (self.dropAsRemove) ? gettext('Remove %s', self.label) : gettext('Delete'),
+          label: (self.dropAsRemove) ? gettext('Remove %s', self.label) : gettext('Drop'),
           data: {
             'url': 'drop',
             data_disabled: gettext('The selected tree node does not support this option.'),
           },
+          shortcut_preference: ['browser', 'sub_menu_delete'],
           enable: _.isFunction(self.canDrop) ?
             function() {
               return !!(self.canDrop(...arguments));
             } : (!!self.canDrop),
-          permission: self.type == 'server' ? 'object_register_server' : undefined,
+          permission: self.type == 'server' ? AllPermissionTypes.OBJECT_REGISTER_SERVER : undefined,
         }]);
 
         if (self.canDropCascade) {
@@ -172,7 +175,7 @@ define('pgadmin.browser.node', [
             applies: ['object', 'context'],
             callback: 'delete_obj',
             priority: 2,
-            label: gettext('Delete (Cascade)'),
+            label: gettext('Drop (Cascade)'),
             data: {
               'url': 'delete',
             },
@@ -204,6 +207,7 @@ define('pgadmin.browser.node', [
           label: gettext('Query Tool'),
           enable: enable,
           permission: AllPermissionTypes.TOOLS_QUERY_TOOL,
+          shortcut_preference: ['browser', 'sub_menu_query_tool'],
         }]);
 
         // show search objects same as query tool
@@ -213,6 +217,7 @@ define('pgadmin.browser.node', [
           priority: 997, label: gettext('Search Objects...'),
           icon: 'fa fa-search', enable: enable,
           permission: AllPermissionTypes.TOOLS_SEARCH_OBJECTS,
+          shortcut_preference: ['browser', 'sub_menu_search_objects'],
         }]);
 
         if(pgAdmin['enable_psql']) {
@@ -526,13 +531,13 @@ define('pgadmin.browser.node', [
         let msg, title;
 
         if (input.url == 'delete' && d._type === 'database') {
-          msg = gettext('Delete database with the force option will attempt to terminate all existing connections to the <b>"%s"</b> database. Are you sure you want to proceed?', d.label);
-          title = gettext('Delete FORCE %s?', obj.label);
+          msg = gettext('Drop database with the force option will attempt to terminate all existing connections to the <b>"%s"</b> database. Are you sure you want to proceed?', d.label);
+          title = gettext('Drop FORCE %s?', obj.label);
 
         } else if (input.url == 'delete') {
-          msg = gettext('Are you sure you want to delete the %s <b>"%s"</b> and all the objects that depend on it?',
+          msg = gettext('Are you sure you want to drop the %s <b>"%s"</b> and all the objects that depend on it?',
             obj.label.toLowerCase(), d.label);
-          title = gettext('Delete CASCADE %s?', obj.label);
+          title = gettext('Drop CASCADE %s?', obj.label);
 
           if (!(_.isFunction(obj.canDropCascade) ?
             obj.canDropCascade(d, i) : obj.canDropCascade)) {
@@ -547,8 +552,8 @@ define('pgadmin.browser.node', [
             msg = gettext('Are you sure you want to remove the %s <b>"%s"</b>?', obj.label.toLowerCase(), d.label);
             title = gettext('Remove %s?', obj.label);
           } else {
-            msg = gettext('Are you sure you want to delete the %s <b>"%s"</b>?', obj.label.toLowerCase(), d.label);
-            title = gettext('Delete %s?', obj.label);
+            msg = gettext('Are you sure you want to drop the %s <b>"%s"</b>?', obj.label.toLowerCase(), d.label);
+            title = gettext('Drop %s?', obj.label);
           }
 
           if (!(_.isFunction(obj.canDrop) ?
@@ -581,6 +586,11 @@ define('pgadmin.browser.node', [
                   }, 10);
                   selectNextNode = false;
                 }
+                if (obj.refreshParent?.(i)) {
+                  obj.callbacks.refresh('refresh', t.parent(i));
+                  return;
+                }
+
                 pgBrowser.removeTreeNode(i, selectNextNode);
               }
               return true;
@@ -599,7 +609,7 @@ define('pgadmin.browser.node', [
             });
           },
           () => {},
-          gettext('Delete'),
+          obj.dropAsRemove ? gettext('Remove') : gettext('Drop'),
           gettext('Cancel'),
         );
       },
@@ -728,9 +738,19 @@ define('pgadmin.browser.node', [
             _item.clear_cache.apply(_item);
           }, 0);
         }
-        pgBrowser.Events.trigger('pgadmin:browser:tree:expand-from-previous-tree-state',
-          item);
         pgBrowser.Node.callbacks.change_server_background(item, data);
+        // Suppress added tree event being called during object search operations
+        // where tree.select clashes due to previous tree state restore
+        const suppressPath = pgBrowser.tree.suppressEventsForPath;
+        if (suppressPath) {
+          if (item.path === suppressPath) {
+            pgBrowser.tree.suppressEventsForPath = null;
+          } else {
+            return;
+          }
+        }
+
+        pgBrowser.Events.trigger('pgadmin:browser:tree:expand-from-previous-tree-state', item);
       },
       // Callback called - when a node is selected in browser tree.
       selected: function(item, data) {
@@ -776,6 +796,16 @@ define('pgadmin.browser.node', [
       opened: function(item) {
         let tree = pgBrowser.tree,
           auto_expand = usePreferences.getState().getPreferences('browser', 'auto_expand_sole_children');
+        // Suppress opened tree event being called during object search operations
+        // where tree.select clashes due to only child of parent opens automatically.
+        const suppressPath = pgBrowser.tree.suppressEventsForPath;
+        if (suppressPath) {
+          if (item.path === suppressPath) {
+            pgBrowser.tree.suppressEventsForPath = null;
+          } else {
+            return;
+          }
+        }
 
         if (auto_expand?.value && tree.children(item).length == 1) {
           // Automatically expand the child node, if a treeview node has only a single child.
