@@ -8,14 +8,14 @@
 //////////////////////////////////////////////////////////////
 
 import { useSingleAndDoubleClick } from '../../../custom_hooks';
-import * as React from 'react';
 import PropTypes from 'prop-types';
 import CustomPropTypes from '../../../../js/custom_prop_types';
-
+import { getEnterKeyHandler } from '../../../../js/utils';
+ 
 export default function DoubleClickHandler({onSingleClick, onDoubleClick, children}){
   const onClick = useSingleAndDoubleClick(onSingleClick, onDoubleClick) ;
   return(
-    <div onClick={(e)=>onClick(e)}>
+    <div onClick={(e)=>onClick(e)} onKeyDown = { getEnterKeyHandler(onClick)}>
       {children}
     </div>
   );
