@@ -311,15 +311,19 @@ def filename_with_file_manager_path(_file, create_file=False,
     elif not os.path.isabs(_file):
         _file = os.path.join(document_dir(), _file)
 
-    def short_filepath():
-        short_path = fs_short_path(_file)
+    def short_filepath(file=_file):
+        short_path = fs_short_path(file)
         # fs_short_path() function may return empty path on Windows
         # if directory doesn't exists. In that case we strip the last path
         # component and get the short path.
         if os.name == 'nt' and short_path == '':
-            base_name = os.path.basename(_file)
-            dir_name = os.path.dirname(_file)
-            short_path = fs_short_path(dir_name) + '\\' + base_name
+            base_name = os.path.basename(file)
+            dir_name = os.path.dirname(file)
+            dir_short_path = fs_short_path(dir_name)
+            if dir_short_path == '' and file != "":
+                short_path = os.path.join(short_filepath(dir_name), base_name)
+            else:
+                short_path = os.path.join(dir_short_path, base_name)
         return short_path
 
     if create_file:
@@ -339,18 +343,18 @@ def does_utility_exist(file):
 
     if file is None:
         error_msg = gettext("Utility file not found. Please correct the Binary"
-                            " Path in the Preferences dialog")
+                            " Path in the Preferences")
         return error_msg
 
     if Path(config.STORAGE_DIR) == Path(file) or \
             Path(config.STORAGE_DIR) in Path(file).parents:
-        error_msg = gettext("Please correct the Binary Path in the Preferences"
-                            " dialog. pgAdmin storage directory can not be a"
-                            " utility binary directory.")
+        error_msg = gettext("Please correct the Binary Path in the "
+                            "Preferences. pgAdmin storage directory can not "
+                            "be a utility binary directory.")
 
     if not os.path.exists(file):
         error_msg = gettext("'%s' file not found. Please correct the Binary"
-                            " Path in the Preferences dialog" % file)
+                            " Path in the Preferences" % file)
     return error_msg
 
 
@@ -513,6 +517,7 @@ def dump_database_servers(output_file, selected_servers,
             add_value(attr_dict, "Shared", server.shared)
             add_value(attr_dict, "SharedUsername", server.shared_username)
             add_value(attr_dict, "DBRestriction", server.db_res)
+            add_value(attr_dict, "DBRestrictionType", server.db_res_type)
             add_value(attr_dict, "BGColor", server.bgcolor)
             add_value(attr_dict, "FGColor", server.fgcolor)
             add_value(attr_dict, "Service", server.service)
@@ -524,6 +529,8 @@ def dump_database_servers(output_file, selected_servers,
                       server.tunnel_authentication)
             add_value(attr_dict, "TunnelIdentityFile",
                       server.tunnel_identity_file)
+            add_value(attr_dict, "TunnelPromptPassword",
+                      server.tunnel_prompt_password)
             add_value(attr_dict, "TunnelKeepAlive",
                       server.tunnel_keep_alive)
             add_value(attr_dict, "KerberosAuthentication",
@@ -732,6 +739,8 @@ def load_database_servers(input_file, selected_servers,
 
             new_server.db_res = obj.get("DBRestriction", None)
 
+            new_server.db_res_type = obj.get("DBRestrictionType", None)
+
             if 'ConnectionParameters' in obj:
                 new_server.connection_params = \
                     obj.get("ConnectionParameters", None)
@@ -770,6 +779,9 @@ def load_database_servers(input_file, selected_servers,
             new_server.tunnel_identity_file = \
                 obj.get("TunnelIdentityFile", None)
 
+            new_server.tunnel_prompt_password = \
+                obj.get("TunnelPromptPassword", 0)
+
             new_server.tunnel_keep_alive = \
                 obj.get("TunnelKeepAlive", None)
 
