@@ -16,7 +16,8 @@ from selenium.webdriver.common.by import By
 from selenium.webdriver import ActionChains
 from selenium.webdriver.common.keys import Keys
 from regression.feature_utils.base_feature_test import BaseFeatureTest
-from regression.feature_utils.locators import NavMenuLocators
+from regression.feature_utils.locators import NavMenuLocators, \
+    PreferencesLocaltors
 
 
 class KeyboardShortcutFeatureTest(BaseFeatureTest):
@@ -88,32 +89,21 @@ class KeyboardShortcutFeatureTest(BaseFeatureTest):
             NavMenuLocators.preference_menu_item_css)
         pref_menu_item.click()
 
-        self.page.find_by_xpath(
-            NavMenuLocators.specified_preference_tree_node.format('Browser'))
+        wait = WebDriverWait(self.page.driver, 10)
 
-        display_node = self.page.find_by_xpath(
-            NavMenuLocators.specified_sub_node_of_pref_tree_node.format(
-                'Browser', 'Display'))
-        attempt = 5
-        while attempt > 0:
-            display_node.click()
-            # After clicking the element gets loaded in to the dom but still
-            # not visible, hence sleeping for a sec.
-            time.sleep(1)
-            if self.page.wait_for_element_to_be_visible(
-                self.driver,
-                    NavMenuLocators.show_system_objects_pref_label_xpath, 3):
-                break
-            else:
-                attempt -= 1
+        self.page.click_tab("Preferences")
 
-        maximize_button = self.page.find_by_css_selector(
-            NavMenuLocators.maximize_pref_dialogue_css)
-        maximize_button.click()
+        # Wait till the preference dialogue box is displayed by checking the
+        # visibility of Show System Object label
+        wait.until(EC.presence_of_element_located(
+            (By.XPATH,
+             PreferencesLocaltors.show_system_objects_pref_label_xpath))
+        )
 
         keyboard_node = self.page.find_by_xpath(
-            NavMenuLocators.specified_sub_node_of_pref_tree_node.format(
-                'Browser', 'Keyboard shortcuts'))
+            PreferencesLocaltors.specified_preference_tree_node_xpath.format(
+                'Keyboard shortcuts'))
+
         keyboard_node.click()
 
         for s in self.new_shortcuts:
@@ -125,7 +115,11 @@ class KeyboardShortcutFeatureTest(BaseFeatureTest):
                                         "input".format(locator))
 
             file_menu.click()
+            time.sleep(1)
             file_menu.send_keys(key)
 
         # save and close the preference dialog.
-        self.page.click_modal('Save')
+        self.page.find_by_css_selector(PreferencesLocaltors.save_btn) \
+            .click()
+        time.sleep(3)
+        self.page.close_active_tab()
