@@ -48,13 +48,13 @@ class NavMenuLocators:
 
     maintenance_obj_css = "li[data-label='Maintenance...']"
 
+    query_tool_menu_css = "li[data-label='Query Tool']"
+
     show_system_objects_pref_label_xpath = \
         "//label[contains(text(), 'Show system objects?')]"
 
     maximize_pref_dialogue_css = "button[data-label='Maximize']"
 
-    maximize_pref_dialogue_css = "button[data-label='Maximize']"
-
     specified_pref_node_exp_status = \
         "//*[@id='treeContainer']//div//span[text()='{0}']"
 
@@ -112,6 +112,18 @@ class NavMenuLocators:
         ".btn.btn-sm-sq.btn-primary.pg-bg-close > i"
 
 
+class PreferencesLocaltors:
+    show_system_objects_pref_label_xpath = \
+        "//label[contains(text(), 'Show system objects?')]"
+
+    specified_preference_tree_node_xpath = \
+        ("//*[@id='treeContainer']//div[contains(@class,'PgTree-nodeLabel')]"
+         "[text()='{0}']")
+
+    save_btn = \
+        "#id-preferences button[data-label='Save']"
+
+
 class QueryToolLocators:
     btn_save_file = "button[data-label='Save File']"
 
@@ -207,7 +219,7 @@ class QueryToolLocators:
     row_editor_text_area_css = "div[data-label='pg-editor'] textarea"
 
     json_editor_text_area_css = \
-        "div.ace_layer.ace_text-layer .ace_line_group .ace_line"
+        "div.jsoneditor-div .jse-contents .cm-editor .cm-content"
 
     row_editor_checkbox_css = "div[data-label='pg-checkbox-editor']"
 
