@@ -152,8 +152,15 @@ class PgadminPage:
     def open_query_tool(self):
         self.click_element(self.find_by_css_selector(
             "button[data-label='Tools']"))
+        WebDriverWait(self.driver, 3).until(
+            EC.visibility_of_element_located(
+                (By.CSS_SELECTOR, NavMenuLocators.query_tool_menu_css)))
+        (ActionChains(self.driver).move_to_element(
+            self.driver.find_element(
+                By.CSS_SELECTOR, NavMenuLocators.query_tool_menu_css))
+         .perform())
         self.click_element(self.find_by_css_selector(
-            "li[data-label='Query Tool']"))
+            NavMenuLocators.query_tool_menu_css))
 
         self.driver.switch_to.default_content()
         WebDriverWait(self.driver, 10).until(
@@ -213,6 +220,11 @@ class PgadminPage:
         else:
             assert False, "'Tools -> Query Tool' menu did not enable."
 
+    def close_active_tab(self):
+        self.find_by_css_selector(f"div[data-dockid='id-main'] "
+                                  ".dock-tab.dock-tab-active "
+                                  "button[data-label='Close']").click()
+
     def close_query_tool(self, prompt=True):
         self.driver.switch_to.default_content()
         time.sleep(.5)
@@ -354,7 +366,7 @@ class PgadminPage:
             self.click_element(self.find_by_css_selector(
                 "li[data-label='Remove Server']"))
             self.driver.switch_to.default_content()
-            self.click_modal('Delete')
+            self.click_modal('Remove')
             time.sleep(1)
         else:
             print(server_config['name'] + " server is not removed",
@@ -502,7 +514,10 @@ class PgadminPage:
                 TreeAreaLocators.server_connection_status_element(server_name))
             server_class = server_connection_status_element.get_attribute(
                 'class')
-            if server_class == 'icon-pg' or server_class == 'icon-ppas':
+            print("(click_expand_server_node)"
+                  "server_class = " + str(server_class), file=sys.stderr)
+            if (server_class.find('icon-pg') != -1 or
+                    server_class.find('icon-ppas') != -1):
                 server_connected = True
         except Exception as e:
             print("There is some exception thrown in the function "
